@@ -10,6 +10,7 @@ import sys
 from requests.exceptions import ConnectionError
 import xyz_py as xyzp
 import copy
+from numpy.typing import ArrayLike
 
 # These are VdW radii taken from the 2016/2017
 # CRC Handbook of physics of chemistry
@@ -394,7 +395,7 @@ def get_method(name):
 
 
 def create_title_and_route(method, extra_radii, opt=True, freq=True, ecp=False,
-                           chelpg=False, extra_route=[], extra_title=""):
+                           chelpg='', extra_route=[], extra_title=""):
     """
     Creates title and routecard for Gaussian com file
 
@@ -449,11 +450,15 @@ def create_title_and_route(method, extra_radii, opt=True, freq=True, ecp=False,
     if dft:
         routecard += "empiricaldispersion=gd3 int=grid=ultrafine "
 
-    if chelpg:
-        if extra_radii:
-            routecard += "pop=(CHELPG, AtomDipole, ReadRadii) "
-        else:
-            routecard += "pop=(CHELPG, AtomDipole) "
+    if chelpg == 'charge':
+        routecard += "pop=(CHELPG, Atom"
+    elif chelpg == 'charge_dipole':
+        routecard += "pop=(CHELPG, AtomDipole"
+
+    if chelpg and extra_radii:
+        routecard += ", ReadRadii) "
+    elif chelpg:
+        routecard += ") "
 
     routecard += "scf=(xqc,maxcycle=500) "
 
@@ -493,7 +498,7 @@ def subsititute_element(sub_list, labels, labels_nn):
     # Perform swap for labels and labels_nn
     for it, val in enumerate(labels):
         if old in val:
-            labels_nn[it] = xyzp.remove_numbers([new])[0]
+            labels_nn[it] = xyzp.remove_label_indices([new])[0]
             num = ''
             for c in labels[it]:
                 if c.isdigit():
@@ -638,7 +643,7 @@ def create_com_file(charge, mult, f_name_head, labels, coords,
             for lab, trio in zip(labels, coords):
                 f.write(
                     "{:5}     {:11.7f} {:11.7f} {:11.7f} \n"
-                    .format(lab.capitalize(), frz, *trio)
+                    .format(lab.capitalize(), *trio)
                 )
         f.write("\n")
 
@@ -669,10 +674,12 @@ def create_com_file(charge, mult, f_name_head, labels, coords,
     return
 
 
-def gen_input(f_name, labels, coords, charge, mult, method, bs_spec,
-              ecp_spec={}, subiso=[], chelpg=False, opt=True,
-              freq=True, extra_route=[], extra_title="", verbose=True,
-              frozen=[]):
+def gen_input(f_name: str, labels: list[str], coords: ArrayLike,
+              charge: int, mult: int, method: str, bs_spec: dict[str: str],
+              ecp_spec: dict = {str: str}, subiso=[], chelpg: str = '',
+              opt: bool = True, freq: bool = True, extra_route: list[str] = [],
+              extra_title: str = "", verbose: bool = True,
+              frozen: list = [str]):
     """
     Generates Gaussian input .com file ready for use with
     gaussian_suite submit
@@ -713,9 +720,9 @@ def gen_input(f_name, labels, coords, charge, mult, method, bs_spec,
                 [atom1, atom2, atom2, mass]
             where atomN can contain numbers
             e.g. Dy1 or Dy
-        chelpg : bool, default False
-            If True, enables decomposition of electronic potential using CHELPG
-            scheme
+        chelpg : str {'charge', 'charge_dipole'}
+            If specified, enables decomposition of electronic potential]
+            using CHELPG scheme
         opt : bool, default True
             If True enables optimisation
         freq : bool, default True
@@ -736,7 +743,7 @@ def gen_input(f_name, labels, coords, charge, mult, method, bs_spec,
     """
 
     # Remove numbers
-    labels_nn = xyzp.remove_numbers(labels)
+    labels_nn = xyzp.remove_label_indices(labels)
 
     # Get list of which elements are present
     unique_elements = list(set(labels_nn))
